@@ -112,11 +112,20 @@ class StructureGroupBuilder(Builder):
         """
         q = dict(self.query)
 
-        keys = self.sgroups.newer_in(self.materials, criteria=q, exhaustive=True)
+        all_chemsys = self.materials.distinct("chemsys", criteria=q)
 
-        N = ceil(len(keys) / number_splits)
-        for split in grouper(keys, N):
-            yield {"query": {self.materials.key: {"$in": list(split)}}}
+        new_chemsys_list = []
+
+        for chemsys in all_chemsys:
+            elements = [
+                element for element in chemsys.split("-") if element != self.working_ion
+            ]
+            new_chemsys = "-".join(sorted(elements))
+            new_chemsys_list.append(new_chemsys)
+
+        N = ceil(len(new_chemsys_list) / number_splits)
+        for split in grouper(new_chemsys_list, N):
+            yield {"query": {"chemsys": {"$in": list(split)}}}
 
     def get_items(self):
         """
